==> qtjambi-uic-5.15.9-sources.jar: io/qt/uic/ui4/DomSize.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomSize</p>
 */
public class DomSize extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomSize(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSize instance);
    
    @io.qt.QtUninvokable
    public final void clearElementHeight(){
        clearElementHeight_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHeight_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementWidth(){
        clearElementWidth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementWidth_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementHeight(){
        return elementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementHeight_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementWidth(){
        return elementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementWidth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHeight(){
        return hasElementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHeight_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementWidth(){
        return hasElementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementWidth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementHeight(int a){
        setElementHeight_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementHeight_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementWidth(int a){
        setElementWidth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementWidth_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomSize(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-5.15.16-sources.jar: io/qt/uic/ui4/DomSize.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomSize</code></p>
 */
public class DomSize extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomSize::<wbr>DomSize()</code></p>
     */
    public DomSize(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSize instance);
    
    /**
     * <p>See <code>DomSize::<wbr>clearElementHeight()</code></p>
     */
    @QtUninvokable
    public final void clearElementHeight(){
        clearElementHeight_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHeight_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSize::<wbr>clearElementWidth()</code></p>
     */
    @QtUninvokable
    public final void clearElementWidth(){
        clearElementWidth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementWidth_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSize::<wbr>elementHeight()const</code></p>
     */
    @QtUninvokable
    public final int elementHeight(){
        return elementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSize::<wbr>elementWidth()const</code></p>
     */
    @QtUninvokable
    public final int elementWidth(){
        return elementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSize::<wbr>hasElementHeight()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHeight(){
        return hasElementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSize::<wbr>hasElementWidth()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementWidth(){
        return hasElementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSize::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomSize::<wbr>setElementHeight(int)</code></p>
     */
    @QtUninvokable
    public final void setElementHeight(int a){
        setElementHeight_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHeight_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomSize::<wbr>setElementWidth(int)</code></p>
     */
    @QtUninvokable
    public final void setElementWidth(int a){
        setElementWidth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementWidth_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomSize::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomSize(QPrivateConstructor p) { super(p); } 
    
}
